Learn R Programming

insulin.secretion (version 0.0.2)

isr.longHL: C-Peptide Long Half Life Calculator

Description

Outputs the long half life based on patient age for use in isr.deconv() per the Van Cauter method of estimating insulin secretion rate.

Usage

isr.longHL(subject.age)

Value

Numeric value.

Arguments

subject.age

Numeric for patient age in years.

See Also

isr.deconv()

Examples

Run this code
isr.longHL(18.08)

Run the code above in your browser using DataLab