powered by
Outputs the long half life based on patient age for use in isr.deconv() per the Van Cauter method of estimating insulin secretion rate.
isr.deconv()
isr.longHL(subject.age)
Numeric value.
Numeric for patient age in years.
isr.longHL(18.08)
Run the code above in your browser using DataLab